@@ -15,22 +15,23 @@ from en.dims import docs_to_dims
 attach = lambda doc: ( terms.attach(doc), verbnet.attach(doc), doc.user_data )[-1]  # return ssv, defaultdict(dict)
 
 def index_doc(did, doc):  
-	dic = {}
+	''' arr: additional attr, such as filename , '''
+	arr  = {"did": did}
 	snts = [snt.text for snt in doc.sents]
 	docs = [snt.as_doc() for snt in doc.sents] #spacy.getdoc(snt)
 	dims = docs_to_dims(snts, docs)
 	dims.update({'type':'doc', "sntnum":len(snts), "wordnum": sum([ len(snt) for snt in snts]), 'tm': time.time()})
-	dic[did] = dims 
+	arr[did] = dims 
 
 	for idx, sdoc in enumerate(docs):
-		dic[f"{did}-{idx}"] = {'type':'snt', 'snt':snts[idx], 'pred_offset': en.pred_offset(sdoc), 
+		arr[f"{did}-{idx}"] = {'type':'snt', 'snt':snts[idx], 'pred_offset': en.pred_offset(sdoc), 
 				'postag':' '.join([f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}" if t.text == t.text.lower() else f"{t.text}_{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in sdoc]),
 				'src': f"{did}-{idx}",  'tc': len(sdoc)} # src = sentid 
 		ssv = attach(sdoc) 
 		for id, sour in ssv.items():
 			sour.update({"src":f"{did}-{idx}"}) # sid
-			dic[f"{did}-{idx}-{id}"] = sour
-	return dic
+			arr[f"{did}-{idx}-{id}"] = sour
+	return arr
 
 @app.get('/en/esdoc')
 def esdoc(text:str="The quick fox jumped over the lazy dog. Justice delayed is justice denied.", did:str=None):  
@@ -87,10 +88,8 @@ class util(object):
 	def __init__(self): pass 
 
 	def hello(self):
-		doc = spacy.getdoc("The quick fox jumped over the lazy dog.")
-		terms.attach(doc) 
-		verbnet.attach(doc)
-		print(doc.user_data)
+		print(esdoc())
+		print (annotate()) 
 
 	def uvirun(self, port) : 
 		''' python -m en uvirun 8000 '''
@@ -104,7 +103,6 @@ class util(object):
 
 if __name__ == '__main__':
 	print(esdoc())
-	print (annotate()) 
 	#fire.Fire(util)
 
 '''
