@@ -138,7 +138,7 @@ def attach(doc):
 
 	# last to be called , added 2022.3.24,   in ES:  skenp:postag , to searh "_^ _IN _NP ," , in paper ratio
 	merge_np(doc) 
-	doc.user_data["skenp"] = "_^ " + " ".join([ "_NP" if t.ent_type_ == 'NP' else f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc]) + " _$"
+	doc.user_data["skenp"] = {"type":"skenp", "chunk": "_^ " + " ".join([ "_NP" if t.ent_type_ == 'NP' else f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc]) + " _$"}
 
 if __name__ == "__main__":  
 	doc = spacy.nlp("Considering the possibility, it was ok, and she is ok.")
@@ -170,4 +170,27 @@ def submit_verbnet(sid, doc, ssv): 	#ssv = defaultdict(dict)
 	for ibeg, lem, chunk in doc_to_verbnet(doc): 
 		ssv[f"{sid}-verbnet-{ibeg}"].update ({"type":"verbnet","lem":lem,"chunk":chunk})
 
+[['S.conj', 2423],
+ ['S.relcl', 2058],
+ ['S.advcl', 1982],
+ ['S.ccomp', 1294],
+ ['S.xcomp', 1196],
+ ['S.acl', 1101],
+ ['S.pcomp', 585],
+ ['S.csubj', 66],
+ ['S.dep', 38],
+ ['S.acomp', 31],
+ ['S.parataxis', 31],
+ ['S.prep', 31],
+ ['S.pobj', 27],
+ ['S.amod', 19],
+ ['S.nmod', 9],
+ ['S.csubjpass', 7],
+ ['S.dobj', 6],
+ ['S.oprd', 5],
+ ['S.attr', 4],
+ ['S.nsubj', 4],
+ ['S.nsubjpass', 3],
+ ['S.appos', 1]]
+
 '''
\ No newline at end of file
