@@ -124,6 +124,8 @@ config = {
 			"tmf": { "type": "float"},
 			"stroke": { "type": "keyword", "index": "false"},
 			"strokes": { "type": "keyword", "index": "false"},
+			"_snt": { "type": "keyword", "index": "false"},
+			"_ske": { "type": "keyword", "index": "false"},
 			"en": { "type": "text", "analyzer": "standard","fielddata":"true"},
 			"content": { "type": "text", "analyzer": "standard","fielddata":"true"},
 			"zhseg": { "type": "text", "analyzer": "standard"},
@@ -162,6 +164,25 @@ config = {
 					  "i": {"type": "integer"}
 				   }
 				},
+			 "sntvec": {
+			   "type": "dense_vector",
+			   "dims": 384,
+			   "index": True,
+			   "similarity": "l2_norm"
+			 },
+			 "skevec": {  # _NP jumped over _NP
+			   "type": "dense_vector",
+			   "dims": 384,
+			   "index": True,
+			   "similarity": "l2_norm"
+			 },
+			"vec": {
+				   "type": "dense_vector",
+				   "dims": 384, # use sbert 
+				   "index": "true",
+				   "similarity": "l2_norm"
+				 },
+
 			"err": {"type": "text",  "analyzer": "err_ana"},
 			"fd": { "type": "keyword"},
 			"short_msg": { "type": "keyword"},
@@ -320,4 +341,98 @@ PUT twitter/_mapping
     }
   }
 }
+
+
+PUT my_index
+{
+  "mappings": {
+    "properties": {
+      "my_vector": {
+        "type": "dense_vector",
+        "dims": 4
+      },
+      "my_text" : {
+        "type" : "keyword"
+      }
+    }
+  }
+}
+
+GET my_index/_search
+{
+  "query": {
+    "script_score": {
+      "query": {
+        "match_all": {}
+      },
+      "script": {
+        "source": "cosineSimilarity(params.query_vector, 'my_vector') + 1.0",
+        "params": {
+          "query_vector": [ 1,2,3]
+        }
+      }
+    }
+  }
+}
+
+
+PUT my_index/_doc/1
+{
+  "my_text" : "text1",
+  "my_vector" : [0.5, 10, 6, 3]
+}
+
+PUT my_index/_doc/2
+{
+  "my_text" : "text2",
+  "my_vector" : [-0.5, 10, 10, 4]
+}
+
+GET /my_index/_search
+{
+  "query": {
+    "match_all": { }
+  }
+}
+
+essaydm.wrask.com 
+ubuntu@VM-171-3-ubuntu:/data$ runlike es
+docker run --name=es --hostname=db25101107b8 --user=elasticsearch --mac-address=02:42:ac:12:00:02 --env=discovery.type=single-node --env=PATH=/usr/local/openjdk-11/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin --env=LANG=C.UTF-8 --env=JAVA_HOME=/usr/local/openjdk-11 --env=JAVA_VERSION=11.0.9.1 --env=EK_VERSION=7.15.1 --volume=/ftp/es-9200-eevsnts:/home/elasticsearch/elasticsearch-7.15.1/data --workdir=/home/elasticsearch -p 5601:5601 -p 9200:{esport} --restart=always --label='maintainer=nshou <nshou@coronocoya.net>' --runtime=runc --detach=true nshou/elasticsearch-kibana /bin/sh -c 'elasticsearch-${EK_VERSION}/bin/elasticsearch -E http.host=0.0.0.0 --quiet & kibana-${EK_VERSION}-linux-x86_64/bin/kibana --allow-root --host 0.0.0.0 -Q'
+
+#https://www.elastic.co/cn/blog/introducing-approximate-nearest-neighbor-search-in-elasticsearch-8-0
+
+PUT index
+{
+ "mappings": {
+   "properties": {
+     "image-vector": {
+       "type": "dense_vector",
+       "dims": 128,
+       "index": true,
+       "similarity": "l2_norm"
+     }
+   }
+ }
+}
+
+POST index/_doc
+{
+ "image-vector": [0.12, 1.34, 3.4]
+}
+
+GET index/_knn_search
+{
+ "knn": {
+   "field": "image-vector",
+   "query_vector": [-0.5, 9.4, 3],
+   "k": 10,
+   "num_candidates": 100
+ }
+}
+
+from dic.word_awl import word_awl 
+@app.get("/corpus/word_awl")
+def corpus_word_awl(index:str='gzjc', topk:int=10): 
+	return (si:= Counter(), [si.update({s:i}) for s,i in rows(f"select lem, count(*) from {index} where type = 'tok' group by lem") if s in word_awl ], si.most_common(topk))[-1]
+
 '''
\ No newline at end of file
