@@ -33,6 +33,14 @@ class ES(object):
 			self.es.index(index = idxname, id = id, body = sv)
 		print("annotate finished:", infile,idxname)
 
+	def add(self, infile, idxname="testdoc"):
+		''' add doc only , 2022.3.25 '''
+		if not self.es.indices.exists(idxname): self.es.indices.create(idxname, config)
+		text = open(infile, 'r').read().strip() 
+		did	 = hashlib.md5(text.encode("utf8")).hexdigest()
+		res  = self.es.index(index=idxname, body={"doc":text,  "filename": infile, 'type':'doc'}, id = did)
+		print("finished:", infile, idxname,res) 
+
 	def loadjukuu(self, infile, idxname, batch=100000): 
 		''' 2022.1.11 '''
 		print("loadsource started:", infile, idxname, self.es, flush=True)
